@@ -749,6 +749,26 @@ void _IKEC::run()
 		}
 	}
 
+	// policy type
+
+	peer.plcy_level = POLICY_LEVEL_AUTO;
+
+	if( config.get_string( "policy-level", text, MAX_CONFSTRING, 0 ) )
+	{
+		if( !strcmp( "use", text ) )
+			peer.plcy_level = POLICY_LEVEL_USE;
+
+		if( !strcmp( "require", text ) )
+			peer.plcy_level = POLICY_LEVEL_REQUIRE;
+
+		if( !strcmp( "unique", text ) )
+			peer.plcy_level = POLICY_LEVEL_UNIQUE;
+
+		if( !strcmp( "shared", text ) )
+			peer.plcy_level = POLICY_LEVEL_SHARED;
+	}
+
+
 	// nailed policy enable
 
 	numb = 0;
@@ -976,7 +996,7 @@ void _IKEC::run()
 		if( msgres == IKEI_RESULT_PASSWD )
 		{
 			FilePassData PassData;
-			PassData.filepath = text;
+			PassData.filepath = btext.text();
 			QApplication::postEvent( r, new FilePassEvent( &PassData ) );
 			while( PassData.result == -1 )
 				msleep( 10 );
@@ -1024,7 +1044,7 @@ void _IKEC::run()
 		if( msgres == IKEI_RESULT_PASSWD )
 		{
 			FilePassData PassData;
-			PassData.filepath = text;
+			PassData.filepath = btext.text();
 			QApplication::postEvent( r, new FilePassEvent( &PassData ) );
 			while( PassData.result == -1 )
 				msleep( 10 );
@@ -1068,7 +1088,7 @@ void _IKEC::run()
 		if( msgres == IKEI_RESULT_PASSWD )
 		{
 			FilePassData PassData;
-			PassData.filepath = text;
+			PassData.filepath = btext.text();
 			QApplication::postEvent( r, new FilePassEvent( &PassData ) );
 			while( PassData.result == -1 )
 				msleep( 10 );
