@@ -60,7 +60,14 @@ long _IKED::socket_dhcp_create( IDB_TUNNEL * tunnel )
 	// create dhcp hw address id
 	//
 
-	rand_bytes( &tunnel->dhcp_hwaddr, 5 );
+	uint32_t peer_addr = tunnel->saddr_r.saddr4.sin_addr.s_addr;
+
+	tunnel->dhcp_hwaddr[ 0 ] = 0x40;			// locally administered unicast MAC
+	tunnel->dhcp_hwaddr[ 1 ] = dhcp_seed[ 1 ];
+	tunnel->dhcp_hwaddr[ 2 ] = dhcp_seed[ 2 ] ^ ( ( peer_addr >> 0 ) & 0xff );
+	tunnel->dhcp_hwaddr[ 3 ] = dhcp_seed[ 3 ] ^ ( ( peer_addr >> 8 ) & 0xff ); 
+	tunnel->dhcp_hwaddr[ 4 ] = dhcp_seed[ 4 ] ^ ( ( peer_addr >> 16 ) & 0xff );
+	tunnel->dhcp_hwaddr[ 5 ] = dhcp_seed[ 5 ] ^ ( ( peer_addr >> 24 ) & 0xff );
 
 	//
 	// create dhcp socket
@@ -78,7 +85,7 @@ long _IKED::socket_dhcp_create( IDB_TUNNEL * tunnel )
 	//
 
 	struct sockaddr_in saddr = tunnel->saddr_l.saddr4;
-	saddr.sin_port = htons( UDP_PORT_DHCPC );
+	saddr.sin_port = htons( UDP_PORT_DHCPS );
 
 	if( bind( tunnel->dhcp_sock, ( sockaddr * ) &saddr, sizeof( saddr ) ) < 0 )
 	{
@@ -233,10 +240,6 @@ long _IKED::process_dhcp_send( IDB_TUNNEL * tunnel )
 		// create dhcp discover packet
 		//
 
-		in_addr src, dst;
-		memcpy( &src, &tunnel->saddr_l.saddr4.sin_addr, sizeof( src ) );
-		memcpy( &dst, &tunnel->saddr_r.saddr4.sin_addr, sizeof( dst ) );
-
 		PACKET packet;
 
 		DHCP_HEADER dhcp_head;
@@ -248,10 +251,13 @@ long _IKED::process_dhcp_send( IDB_TUNNEL * tunnel )
 		dhcp_head.hlen = 6;						// hardware address length
 		dhcp_head.xid = tunnel->dhcp_xid;		// transaction id
 
-		dhcp_head.chaddr[ 0 ] = 0x40;			// locally administered unicast MAC
+		dhcp_head.hops = 1;                     // router IP ( fake relay )
+		dhcp_head.giaddr =                      // ...
+			tunnel->saddr_l.saddr4.sin_addr.s_addr;
+
 		memcpy(									// local hardware address id
-			dhcp_head.chaddr + 1,
-			tunnel->dhcp_hwaddr, 5 );
+			dhcp_head.chaddr,					// ...
+			tunnel->dhcp_hwaddr, 6 );			// ...
 
 		packet.add(
 			&dhcp_head,
@@ -287,10 +293,6 @@ long _IKED::process_dhcp_send( IDB_TUNNEL * tunnel )
 		// create dhcp request packet
 		//
 
-		in_addr src, dst;
-		memcpy( &src, &tunnel->saddr_l.saddr4.sin_addr, sizeof( src ) );
-		memcpy( &dst, &tunnel->saddr_r.saddr4.sin_addr, sizeof( dst ) );
-
 		PACKET packet;
 
 		DHCP_HEADER dhcp_head;
@@ -302,10 +304,13 @@ long _IKED::process_dhcp_send( IDB_TUNNEL * tunnel )
 		dhcp_head.hlen = 6;						// hardware address length
 		dhcp_head.xid = tunnel->dhcp_xid;		// transaction id
 
-		dhcp_head.chaddr[ 0 ] = 0x40;			// locally administered unicast MAC
+		dhcp_head.hops = 1;                     // router IP ( fake relay )
+		dhcp_head.giaddr =                      // ...
+			tunnel->saddr_l.saddr4.sin_addr.s_addr;
+
 		memcpy(									// local hardware address id
-			dhcp_head.chaddr + 1,
-			tunnel->dhcp_hwaddr, 5 );
+			dhcp_head.chaddr,					// ...
+			tunnel->dhcp_hwaddr, 6 );			// ...
 
 		packet.add(
 			&dhcp_head,
