@@ -165,7 +165,7 @@ long _IKED::process_inform_send( IDB_PH1 * ph1, IDB_XCH * inform )
 			inform->hash_l.buff(),
 			inform->hash_l.size() );
 
-		phase2_gen_iv( ph1, inform->msgid, inform->iv );
+		inform->new_msgiv( ph1 );
 	}
 
 	//
@@ -194,9 +194,8 @@ long _IKED::process_inform_recv( IDB_PH1 * ph1, PACKET_IKE & packet, unsigned ch
 	// informational exchange
 	//
 
-	packet.get_msgid( inform.msgid );
-
-	phase2_gen_iv( ph1, inform.msgid, inform.iv );
+	inform.msgid = packet.get_msgid();
+	inform.new_msgiv( ph1 );
 
 	//
 	// decrypt packet
@@ -342,7 +341,7 @@ long _IKED::process_inform_recv( IDB_PH1 * ph1, PACKET_IKE & packet, unsigned ch
 		//
 
 		if( packet.get_payload_left() )
-			log.txt( LLOG_ERROR, "XX : warning, unprocessed payload data !!!\n" );
+			log.txt( LLOG_ERROR, "!! : unprocessed payload data !!!\n" );
 
 		//
 		// check the result
@@ -545,6 +544,102 @@ long _IKED::inform_chk_notify( IDB_PH1 * ph1, IKE_NOTIFY * notify, bool secure )
 		{
 			switch( notify->code )
 			{
+				case ISAKMP_N_UNITY_LOAD_BALANCE:
+				{
+					if( notify->data.size() != sizeof( in_addr ) )
+					{
+						log.txt( LLOG_ERROR, "!! : UNITY-LOAD-BALANCE address data is invalid ( %i bytes )\n", notify->data.size() );
+						break;
+					}
+
+					in_addr addr;
+					notify->data.get( &addr, sizeof( addr ) );
+
+					char txtaddr[ LIBIKE_MAX_TEXTADDR ];
+					text_addr( txtaddr, addr );
+
+					//
+					// only migrate if we have yet to setup
+					// the tunnel policies and routes
+					//
+
+					if( ph1->tunnel->tstate & TSTATE_VNET_CONFIG )
+					{
+						log.txt( LLOG_INFO, "ii : UNITY-LOAD-BALANCE request ignored ( tunnel already mature )\n" );
+						break;
+					}
+
+					log.txt( LLOG_INFO, "ii : UNITY-LOAD-BALANCE requested migration to %s\n", txtaddr );
+
+					//
+					// create a new phase1 object
+					//
+
+					IDB_PH1 * ph1_ulb = new IDB_PH1( ph1->tunnel, true, NULL );
+					ph1_ulb->add( true );
+
+					//
+					// flag our existing phase1 object for removal
+					//
+
+					ph1->inc( true );
+					ph1->status( XCH_STATUS_DEAD, XCH_NORMAL, 0 );
+					ph1->dec( true );
+
+					//
+					// re-initialize our tunnel state
+					//
+					// NOTE : we should probably find a better way
+					// to handle this. having this code here is a
+					// bit hackish but we cant use a new tunnel as
+					// the admin thread retains a pointer to the
+					// object for its own use. our only option is
+					// to recycle the existing tunnel and peer.
+					//
+
+					if( iked.ith_timer.del( &ph1->tunnel->event_dhcp ) )
+						ph1->tunnel->dec( true );
+
+					if( iked.ith_timer.del( &ph1->tunnel->event_dpd ) )
+						ph1->tunnel->dec( true );
+
+					if( iked.ith_timer.del( &ph1->tunnel->event_natt ) )
+						ph1->tunnel->dec( true );
+
+					ph1_ulb->tunnel->tstate = 0;
+					ph1_ulb->tunnel->lstate = 0;
+					ph1_ulb->tunnel->natt_version = IPSEC_NATT_NONE;
+
+					ph1_ulb->tunnel->stats.dpd = false;
+					ph1_ulb->tunnel->stats.frag = false;
+					ph1_ulb->tunnel->stats.natt = false;
+
+					//
+					// update the peer and tunnel objects to use
+					// the address received in the notify data
+					//
+
+					ph1_ulb->tunnel->peer->saddr.saddr4.sin_addr = addr;
+					ph1_ulb->tunnel->saddr_r = ph1_ulb->tunnel->peer->saddr;
+					ph1_ulb->tunnel->saddr_l.saddr4.sin_port = htons( 500 );
+
+					//
+					// reinitialize our filter
+					//
+#ifdef WIN32
+					iked.tunnel_filter_del( ph1_ulb->tunnel );
+					iked.tunnel_filter_add( ph1_ulb->tunnel, false );
+#endif
+					//
+					// initiate new phase1
+					//
+
+					process_phase1_send( ph1_ulb );
+					ph1_ulb->dec( true );
+
+					break;
+				}
+
 				case ISAKMP_N_DPD_R_U_THERE:
 				{
 					uint32_t sequence;
@@ -696,8 +791,8 @@ long _IKED::inform_chk_notify( IDB_PH1 * ph1, IKE_NOTIFY * notify, bool secure )
 								proposal_l->life_sec = lsecs;
 								proposal_r->life_sec = lsecs;
 
-								log.txt( LLOG_DEBUG, "XX : spi_l = 0x%08x\n", ntohl( proposal_l->spi.spi ) );
-								log.txt( LLOG_DEBUG, "XX : spi_r = 0x%08x\n", ntohl( proposal_r->spi.spi ) );
+								log.txt( LLOG_DEBUG, "ii : spi_l = 0x%08x\n", ntohl( proposal_l->spi.spi ) );
+								log.txt( LLOG_DEBUG, "ii : spi_r = 0x%08x\n", ntohl( proposal_r->spi.spi ) );
 								pindex++;
 							}
 						}
@@ -853,7 +948,7 @@ long _IKED::inform_new_notify( IDB_PH1 * ph1, IDB_PH2 * ph2, unsigned short code
 	//
 
 	IDB_INF inform;
-	rand_bytes( &inform.msgid, 4 );
+	inform.new_msgid();
 
 	//
 	// will this be a phase1 or phase2 notification
@@ -958,7 +1053,7 @@ long _IKED::inform_new_delete( IDB_PH1 * ph1, IDB_PH2 * ph2 )
 	//
 
 	IDB_INF inform;
-	rand_bytes( &inform.msgid, 4 );
+	inform.new_msgid();
 
 	//
 	// will this be a phase1 or phase2 notification
