@@ -403,6 +403,12 @@
 
 // unity configuration attributes
 
+#ifdef WIN32
+#define UNITY_APP_VERSION_STRING	"Cisco Systems VPN Client 4.8.01.0300:WinNT"
+#else
+#define UNITY_APP_VERSION_STRING	"Cisco Systems VPN Client 4.8.01 (0640):Linux"
+#endif
+
 #define UNITY_BANNER				28672	// variable
 #define UNITY_SAVE_PASSWD			28673	// basic
 #define UNITY_DEF_DOMAIN			28674	// variable
@@ -503,6 +509,12 @@
 #define POLICY_MODE_COMPAT		1
 #define POLICY_MODE_CONFIG		2
 
+#define POLICY_LEVEL_AUTO		0
+#define POLICY_LEVEL_USE		1
+#define POLICY_LEVEL_REQUIRE	2
+#define POLICY_LEVEL_UNIQUE		3
+#define POLICY_LEVEL_SHARED		4
+
 //
 // IKE structures and classes
 //
@@ -611,6 +623,7 @@ typedef struct _IKE_PEER
 	unsigned char	idtype_r;
 
 	long			plcy_mode;
+	long			plcy_level;
 	long			xconf_mode;
 
 }IKE_PEER;
@@ -628,7 +641,7 @@ typedef struct _IKE_XAUTH
 
 typedef struct _IKE_NSCFG
 {
-	bool		dhcp_dnss;						// dns server list from dhcp
+	bool		dnss_from_dhcp;					// dns server list obtained from dhcp
 	in_addr		dnss_list[ IPSEC_DNSS_MAX ];	// dns server list
 	uint32_t	dnss_count;						// dns server count
 	uint32_t	dnss_nodyn;						// dns dynamic update disabled
