@@ -835,7 +835,7 @@ bool _IDB_PH1::frag_add( unsigned char * data, unsigned long size, long index, b
 bool _IDB_PH1::frag_get( PACKET_IKE & packet )
 {
 	bool frag_done = false;
-	int	frag_index = 1;
+	int  frag_index = 1;
 
 	//
 	// check to see if we have a
@@ -849,12 +849,12 @@ bool _IDB_PH1::frag_get( PACKET_IKE & packet )
 		// and look for the next index
 		//
 
-		int count = frags.count();
-		int index = 0;
+		int list_count = frags.count();
+		int list_index = 0;
 
-		for( ; index < count; index++ )
+		for( ; list_index < list_count; list_index++ )
 		{
-			IKE_FRAG * frag = static_cast<IKE_FRAG*>( frags.get_entry( index ) );
+			IKE_FRAG * frag = static_cast<IKE_FRAG*>( frags.get_entry( list_index ) );
 
 			//
 			// does this match our next index
@@ -878,6 +878,13 @@ bool _IDB_PH1::frag_get( PACKET_IKE & packet )
 				//
 
 				frag_index++;
+
+				//
+				// reset the fragement list index
+				//
+
+				list_index = -1;
+
 				continue;
 			}
 		}
@@ -889,7 +896,7 @@ bool _IDB_PH1::frag_get( PACKET_IKE & packet )
 		// complete packet yet
 		//
 
-		if( index == count )
+		if( list_index == list_count )
 			return false;
 	}
 
@@ -909,12 +916,12 @@ bool _IDB_PH1::frag_get( PACKET_IKE & packet )
 		// and look for the next index
 		//
 
-		int count = frags.count();
-		int index = 0;
+		int list_count = frags.count();
+		int list_index = 0;
 
-		for( ; index < count; index++ )
+		for( ; list_index < list_count; list_index++ )
 		{
-			IKE_FRAG * frag = static_cast<IKE_FRAG*>( frags.get_entry( index ) );
+			IKE_FRAG * frag = static_cast<IKE_FRAG*>( frags.get_entry( list_index ) );
 
 			//
 			// does this match our next index
@@ -944,6 +951,13 @@ bool _IDB_PH1::frag_get( PACKET_IKE & packet )
 				//
 
 				frag_index++;
+
+				//
+				// reset the fragement list index
+				//
+
+				list_index = -1;
+
 				continue;
 			}
 		}
