@@ -187,8 +187,11 @@ _IDB_POLICY::_IDB_POLICY( PFKI_SPINFO * spinfo )
 	memset( &sp, 0, sizeof( sp ) );
 	memset( xforms, 0, sizeof( xforms ) );
 
-	route = false;
+	route_added = false;
+	memset( &route_entry, 0, sizeof( route_entry ) );
+
 	nailed = false;
+	initial = false;
 
 	iked.rand_bytes( &spinfo->seq, sizeof( spinfo->seq ) );
 
@@ -204,9 +207,9 @@ _IDB_POLICY::~_IDB_POLICY()
 // abstract functions from parent class
 //
 
-char * _IDB_POLICY::name()
+const char * _IDB_POLICY::name()
 {
-	static char * xname = "policy";
+	static const char * xname = "policy";
 	return xname;
 }
 
