@@ -338,7 +338,7 @@ bool _IKED::ph2id_paddr( IKE_PH2ID & ph2id, PFKI_ADDR & paddr )
 	return false;
 }
 
-long _IKED::pfkey_init_phase2( bool nailed, u_int16_t plcytype, u_int32_t plcyid, u_int32_t seq )
+long _IKED::pfkey_init_phase2( bool nail, u_int16_t plcytype, u_int32_t plcyid, u_int32_t seq )
 {
 	//
 	// locate oubound policy by id
@@ -370,7 +370,7 @@ long _IKED::pfkey_init_phase2( bool nailed, u_int16_t plcytype, u_int32_t plcyid
 	// in the form of an aquire
 	//
 
-	if( policy_out->nailed && !nailed )
+	if( policy_out->nailed && !nail )
 	{
 		log.txt( LLOG_INFO, "ii : ignoring init phase2 by acquire, tunnel is nailed\n" );
 
@@ -525,11 +525,29 @@ long _IKED::pfkey_init_phase2( bool nailed, u_int16_t plcytype, u_int32_t plcyid
 	}
 
 	//
-	// configure client nailed policy id
+	// store the policy ids
+ 	//
+ 
+	ph2->plcyid_in = policy_in->sp.id;
+	ph2->plcyid_out = policy_out->sp.id;
+
+	//
+	// store the nailed sa option
 	//
 
-	if( nailed )
-		ph2->nailed_plcyid = policy_out->sp.id;
+	ph2->nailed = nail;
+
+ 	//
+	// if the tunnel uses shared policy level, we
+	// use a remote ID of 0.0.0.0/0 regardless of
+	// the sa ID value
+	//
+
+	if( tunnel->peer->plcy_level == POLICY_LEVEL_SHARED )
+	{
+		idd.addr1.s_addr = 0;
+		idd.addr2.s_addr = 0;
+	}
 
 	//
 	// configure the phase2 network ids
