@@ -203,6 +203,32 @@ bool _IKED::policy_list_create( IDB_TUNNEL * tunnel, bool initiator )
 		}
 	}
 
+ 	//
+	// determine ipsec policy level value
+	//
+
+	u_int8_t ipsec_level = IPSEC_LEVEL_DEFAULT;
+
+	switch( tunnel->peer->plcy_level )
+	{
+		case POLICY_LEVEL_USE:
+			ipsec_level = IPSEC_LEVEL_USE;
+			break;
+
+		case POLICY_LEVEL_SHARED:
+		case POLICY_LEVEL_REQUIRE:
+			ipsec_level = IPSEC_LEVEL_REQUIRE;
+			break;
+
+		case POLICY_LEVEL_UNIQUE:
+			ipsec_level = IPSEC_LEVEL_UNIQUE;
+			break;
+	}
+
+	log.txt( LLOG_DEBUG,
+		"ii : generating IPSEC security policies at %s level\n",
+		pfki.name( NAME_SPLEVEL, ipsec_level ) );
+
 	//
 	// if we have a empty remote toplology
 	// list, add a single all-networks id
@@ -223,23 +249,38 @@ bool _IKED::policy_list_create( IDB_TUNNEL * tunnel, bool initiator )
 	}
 
 	//
-	// if we will be forcing all traffic
-	// via this tunnel, add none policies
-	// to ensure we will still communicate
-	// with our peer
+	// add NONE policies to ensure we will
+	// still communicate with our peer for
+	// the case where IPSEC policies exist
+	// that encrypt traffic between client
+	// and gateway endpoint addresses
 	//
 
-	if( tunnel->force_all )
+	memset( &id1, 0, sizeof( id1 ) );
+	id1.type = ISAKMP_ID_IPV4_ADDR;
+	id1.addr1 = tunnel->saddr_l.saddr4.sin_addr;
+
+	memset( &id2, 0, sizeof( id2 ) );
+	id2.type = ISAKMP_ID_IPV4_ADDR;
+	id2.addr1 = tunnel->saddr_r.saddr4.sin_addr;
+
+	policy_create( tunnel, IPSEC_POLICY_NONE, IPSEC_LEVEL_DEFAULT, id1, id2, true );
+
+	IPROUTE_ENTRY entry;
+	memset( &entry, 0, sizeof( entry ) );
+	entry.addr = tunnel->saddr_r.saddr4.sin_addr;
+
+	if( iproute.best( entry ) && !entry.local )
 	{
 		memset( &id1, 0, sizeof( id1 ) );
 		id1.type = ISAKMP_ID_IPV4_ADDR;
-		id1.addr1 = tunnel->saddr_l.saddr4.sin_addr;
+		id1.addr1 = tunnel->xconf.addr;
 
 		memset( &id2, 0, sizeof( id2 ) );
 		id2.type = ISAKMP_ID_IPV4_ADDR;
-		id2.addr1 = tunnel->saddr_r.saddr4.sin_addr;
+		id2.addr1 = entry.next;
 
-		policy_create( tunnel, IPSEC_POLICY_NONE, id1, id2, true );
+		policy_create( tunnel, IPSEC_POLICY_NONE, IPSEC_LEVEL_DEFAULT, id1, id2, true );
 	}
 
 	//
@@ -261,9 +302,9 @@ bool _IKED::policy_list_create( IDB_TUNNEL * tunnel, bool initiator )
 	while( tunnel->idlist_excl.get( id2, index++ ) )
 	{
 		if( initiator )
-			policy_create( tunnel, IPSEC_POLICY_NONE, id1, id2, true );
+			policy_create( tunnel, IPSEC_POLICY_NONE, IPSEC_LEVEL_DEFAULT, id1, id2, true );
 		else
-			policy_create( tunnel, IPSEC_POLICY_DISCARD, id2, id1, true );
+			policy_create( tunnel, IPSEC_POLICY_DISCARD, IPSEC_LEVEL_DEFAULT, id2, id1, true );
 	}
 
 	//
@@ -276,9 +317,9 @@ bool _IKED::policy_list_create( IDB_TUNNEL * tunnel, bool initiator )
 	while( tunnel->idlist_incl.get( id2, index++ ) )
 	{
 		if( initiator )
-			policy_create( tunnel, IPSEC_POLICY_IPSEC, id1, id2, true );
+			policy_create( tunnel, IPSEC_POLICY_IPSEC, ipsec_level, id1, id2, true );
 		else
-			policy_create( tunnel, IPSEC_POLICY_IPSEC, id2, id1, true );
+			policy_create( tunnel, IPSEC_POLICY_IPSEC, ipsec_level, id1, id2, true );
 	}
 
 	return true;
@@ -286,6 +327,28 @@ bool _IKED::policy_list_create( IDB_TUNNEL * tunnel, bool initiator )
 
 bool _IKED::policy_list_remove( IDB_TUNNEL * tunnel, bool initiator )
 {
+ 	//
+	// determine ipsec policy level value
+	//
+
+	u_int8_t ipsec_level = IPSEC_LEVEL_DEFAULT;
+
+	switch( tunnel->peer->plcy_level )
+	{
+		case POLICY_LEVEL_USE:
+			ipsec_level = IPSEC_LEVEL_USE;
+			break;
+
+		case POLICY_LEVEL_SHARED:
+		case POLICY_LEVEL_REQUIRE:
+			ipsec_level = IPSEC_LEVEL_REQUIRE;
+			break;
+
+		case POLICY_LEVEL_UNIQUE:
+			ipsec_level = IPSEC_LEVEL_UNIQUE;
+			break;
+	}
+
 	//
 	// build the client id
 	//
@@ -309,9 +372,9 @@ bool _IKED::policy_list_remove( IDB_TUNNEL * tunnel, bool initiator )
 	while( tunnel->idlist_incl.get( id2, index++ ) )
 	{
 		if( initiator )
-			policy_remove( tunnel, IPSEC_POLICY_IPSEC, id1, id2, true );
+			policy_remove( tunnel, IPSEC_POLICY_IPSEC, ipsec_level, id1, id2, true );
 		else
-			policy_remove( tunnel, IPSEC_POLICY_IPSEC, id2, id1, true );
+			policy_remove( tunnel, IPSEC_POLICY_IPSEC, ipsec_level, id2, id1, true );
 	}
 
 	//
@@ -324,36 +387,72 @@ bool _IKED::policy_list_remove( IDB_TUNNEL * tunnel, bool initiator )
 	while( tunnel->idlist_excl.get( id2, index++ ) )
 	{
 		if( initiator )
-			policy_remove( tunnel, IPSEC_POLICY_NONE, id1, id2, true );
+			policy_remove( tunnel, IPSEC_POLICY_NONE, IPSEC_LEVEL_DEFAULT, id1, id2, true );
 		else
-			policy_remove( tunnel, IPSEC_POLICY_DISCARD, id2, id1, true );
+			policy_remove( tunnel, IPSEC_POLICY_DISCARD, IPSEC_LEVEL_DEFAULT, id2, id1, true );
 	}
 
 	//
-	// if we added none policies, remove
-	// them now
+	// remove our gateway NONE policies
 	//
 
-	if( tunnel->force_all )
+	memset( &id1, 0, sizeof( id1 ) );
+	id1.type = ISAKMP_ID_IPV4_ADDR;
+	id1.addr1 = tunnel->saddr_l.saddr4.sin_addr;
+
+	memset( &id2, 0, sizeof( id2 ) );
+	id2.type = ISAKMP_ID_IPV4_ADDR;
+	id2.addr1 = tunnel->saddr_r.saddr4.sin_addr;
+
+	policy_remove( tunnel, IPSEC_POLICY_NONE, IPSEC_LEVEL_DEFAULT, id1, id2, true );
+
+	IPROUTE_ENTRY entry;
+	memset( &entry, 0, sizeof( entry ) );
+	entry.addr = tunnel->saddr_r.saddr4.sin_addr;
+
+	if( iproute.best( entry ) && !entry.local )
 	{
 		memset( &id1, 0, sizeof( id1 ) );
 		id1.type = ISAKMP_ID_IPV4_ADDR;
-		id1.addr1 = tunnel->saddr_l.saddr4.sin_addr;
+		id1.addr1 = tunnel->xconf.addr;
 
 		memset( &id2, 0, sizeof( id2 ) );
 		id2.type = ISAKMP_ID_IPV4_ADDR;
-		id2.addr1 = tunnel->saddr_r.saddr4.sin_addr;
+		id2.addr1 = entry.next;
 
-		policy_remove( tunnel, IPSEC_POLICY_NONE, id1, id2, true );
-
-		tunnel->force_all = false;
+		policy_remove( tunnel, IPSEC_POLICY_NONE, IPSEC_LEVEL_DEFAULT, id1, id2, true );
 	}
 
+	if( tunnel->force_all )
+		tunnel->force_all = false;
+
 	return true;
 }
 
 bool _IKED::policy_dhcp_create( IDB_TUNNEL * tunnel )
 {
+ 	//
+	// determine ipsec policy level value
+	//
+
+	u_int8_t ipsec_level = IPSEC_LEVEL_DEFAULT;
+
+	switch( tunnel->peer->plcy_level )
+	{
+		case POLICY_LEVEL_USE:
+			ipsec_level = IPSEC_LEVEL_USE;
+			break;
+
+		case POLICY_LEVEL_SHARED:
+		case POLICY_LEVEL_REQUIRE:
+			ipsec_level = IPSEC_LEVEL_REQUIRE;
+			break;
+
+		case POLICY_LEVEL_UNIQUE:
+			ipsec_level = IPSEC_LEVEL_UNIQUE;
+			break;
+	}
+
 	//
 	// create our DHCP over IPsec policies
 	//
@@ -364,7 +463,7 @@ bool _IKED::policy_dhcp_create( IDB_TUNNEL * tunnel )
 	memset( &src, 0, sizeof( src ) );
 	src.type = ISAKMP_ID_IPV4_ADDR;
 	src.prot = PROTO_IP_UDP;
-	src.port = htons( UDP_PORT_DHCPC );
+	src.port = htons( UDP_PORT_DHCPS );
 	src.addr1 = tunnel->saddr_l.saddr4.sin_addr;
 
 	IKE_PH2ID dst;
@@ -374,11 +473,33 @@ bool _IKED::policy_dhcp_create( IDB_TUNNEL * tunnel )
 	dst.port = htons( UDP_PORT_DHCPS );
 	dst.addr1 = tunnel->saddr_r.saddr4.sin_addr;
 
-	return policy_create( tunnel, IPSEC_POLICY_IPSEC, src, dst, false );
+	return policy_create( tunnel, IPSEC_POLICY_IPSEC, ipsec_level, src, dst, false );
 }
 
 bool _IKED::policy_dhcp_remove( IDB_TUNNEL * tunnel )
 {
+ 	//
+	// determine ipsec policy level value
+	//
+
+	u_int8_t ipsec_level = IPSEC_LEVEL_DEFAULT;
+
+	switch( tunnel->peer->plcy_level )
+	{
+		case POLICY_LEVEL_USE:
+			ipsec_level = IPSEC_LEVEL_USE;
+			break;
+
+		case POLICY_LEVEL_SHARED:
+		case POLICY_LEVEL_REQUIRE:
+			ipsec_level = IPSEC_LEVEL_REQUIRE;
+			break;
+
+		case POLICY_LEVEL_UNIQUE:
+			ipsec_level = IPSEC_LEVEL_UNIQUE;
+			break;
+	}
+
 	//
 	// remove our DHCP over IPsec policies
 	//
@@ -389,7 +510,7 @@ bool _IKED::policy_dhcp_remove( IDB_TUNNEL * tunnel )
 	memset( &src, 0, sizeof( src ) );
 	src.type = ISAKMP_ID_IPV4_ADDR;
 	src.prot = PROTO_IP_UDP;
-	src.port = htons( UDP_PORT_DHCPC );
+	src.port = htons( UDP_PORT_DHCPS );
 	src.addr1 = tunnel->saddr_l.saddr4.sin_addr;
 
 	IKE_PH2ID dst;
@@ -399,10 +520,10 @@ bool _IKED::policy_dhcp_remove( IDB_TUNNEL * tunnel )
 	dst.port = htons( UDP_PORT_DHCPS );
 	dst.addr1 = tunnel->saddr_r.saddr4.sin_addr;
 
-	return policy_remove( tunnel, IPSEC_POLICY_IPSEC, src, dst, false );
+	return policy_remove( tunnel, IPSEC_POLICY_IPSEC, ipsec_level, src, dst, false );
 }
 
-bool _IKED::policy_create( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route )
+bool _IKED::policy_create( IDB_TUNNEL * tunnel, u_int16_t type, u_int8_t level, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route )
 {
 	char txtid_src[ LIBIKE_MAX_TEXTP2ID ];
 	char txtid_dst[ LIBIKE_MAX_TEXTP2ID ];
@@ -424,8 +545,10 @@ bool _IKED::policy_create( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1,
 	{
 		spinfo.xforms[ 0 ].proto = PROTO_IP_ESP;
 		spinfo.xforms[ 0 ].mode = IPSEC_MODE_TUNNEL;
-		spinfo.xforms[ 0 ].level = IPSEC_LEVEL_UNIQUE;
-		spinfo.xforms[ 0 ].reqid = policyid++;
+		spinfo.xforms[ 0 ].level = level;
+
+		if( level == IPSEC_LEVEL_UNIQUE )
+			spinfo.xforms[ 0 ].reqid = policyid++;
 
 		cpy_sockaddr( tunnel->saddr_r.saddr, spinfo.xforms[ 0 ].saddr_src, false );
 		cpy_sockaddr( tunnel->saddr_l.saddr, spinfo.xforms[ 0 ].saddr_dst, false );
@@ -479,8 +602,10 @@ bool _IKED::policy_create( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1,
 	{
 		spinfo.xforms[ 0 ].proto = PROTO_IP_ESP;
 		spinfo.xforms[ 0 ].mode = IPSEC_MODE_TUNNEL;
-		spinfo.xforms[ 0 ].level = IPSEC_LEVEL_UNIQUE;
-		spinfo.xforms[ 0 ].reqid = policyid++;
+		spinfo.xforms[ 0 ].level = level;
+
+		if( level == IPSEC_LEVEL_UNIQUE )
+			spinfo.xforms[ 0 ].reqid = policyid++;
 
 		cpy_sockaddr( tunnel->saddr_l.saddr, spinfo.xforms[ 0 ].saddr_src, false );
 		cpy_sockaddr( tunnel->saddr_r.saddr, spinfo.xforms[ 0 ].saddr_dst, false );
@@ -513,7 +638,7 @@ bool _IKED::policy_create( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1,
 
 	policy->nailed = tunnel->peer->nailed;
 
-	if( tunnel->tstate & TSTATE_POLICY_INIT )
+	if( ( type == IPSEC_POLICY_IPSEC ) && ( tunnel->tstate & TSTATE_POLICY_INIT ) )
 	{
 		tunnel->tstate &= ~TSTATE_POLICY_INIT;
 		policy->initial = true;
@@ -596,7 +721,7 @@ bool _IKED::policy_create( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1,
 	return true;
 }
 
-bool _IKED::policy_remove( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route )
+bool _IKED::policy_remove( IDB_TUNNEL * tunnel, u_int16_t type, u_int8_t level, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route )
 {
 	char txtid_src[ LIBIKE_MAX_TEXTP2ID ];
 	char txtid_dst[ LIBIKE_MAX_TEXTP2ID ];
