@@ -184,6 +184,8 @@ namespace yy{ class conf_parser; };
 #define VEND_SWALL		{ 0x40, 0x4B, 0xF4, 0x39, 0x52, 0x2C, 0xA3, 0xF6 }
 #define VEND_CHKPT		{ 0xf4, 0xed, 0x19, 0xe0, 0xc1, 0x14, 0xeb, 0x51, 0x6f, 0xaa, 0xac, 0x0e, 0xe3, 0x7d, 0xaf, 0x28, 0x07, 0xb4, 0x38, 0x1f }
 
+#define UNITY_FWTYPE	{ 0x80, 0x01, 0x00, 0x01, 0x80, 0x02, 0x00, 0x01, 0x80, 0x03, 0x00, 0x02 };
+
 #define LIBIKE_IKE_PORT			500		// default isakmp port
 #define LIBIKE_NATT_PORT		4500	// default nat-t port
 
@@ -390,6 +392,7 @@ typedef class _IKED
 	char	path_log[ MAX_PATH ];		// logfile path
 	char	path_decrypt[ MAX_PATH ];	// decrypted pcap path
 	char	path_encrypt[ MAX_PATH ];	// encrypted pcap path
+	char	path_dhcp[ MAX_PATH ];		// dhcp seed
 	
 	long	level;				// logging level
 	long	logflags;			// logging options
@@ -461,6 +464,8 @@ typedef class _IKED
 	BDATA	vend_swind;
 	BDATA	vend_chkpt;
 
+	BDATA	unity_fwtype;
+
 	long	dump_decrypt;		// packet dump decoded traffic
 	long	dump_encrypt;		// packet dump encoded traffic
 
@@ -472,6 +477,8 @@ typedef class _IKED
 	_IKED_XAUTH_LOCAL	xauth_local;
 	_IKED_XCONF_LOCAL	xconf_local;
 
+	uint8_t	dhcp_seed[ 6 ];		// DHCP MAC seed value
+
 #ifdef OPT_LDAP
 
 	IKED_XAUTH_LDAP		xauth_ldap;
@@ -609,8 +616,8 @@ typedef class _IKED
 	bool	policy_list_create( IDB_TUNNEL * tunnel, bool initiator );
 	bool	policy_list_remove( IDB_TUNNEL * tunnel, bool initiator );
 
-	bool	policy_create( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route );
-	bool	policy_remove( IDB_TUNNEL * tunnel, u_int16_t type, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route );
+	bool	policy_create( IDB_TUNNEL * tunnel, u_int16_t type, u_int8_t level, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route );
+	bool	policy_remove( IDB_TUNNEL * tunnel, u_int16_t type, u_int8_t level, IKE_PH2ID & id1, IKE_PH2ID & id2, bool route );
 
 	// proposal helper functions
 
@@ -751,7 +758,7 @@ typedef class _IKED
 	bool	paddr_ph2id( PFKI_ADDR & paddr, IKE_PH2ID & ph2id );
 	bool	ph2id_paddr( IKE_PH2ID & ph2id, PFKI_ADDR & paddr );
 
-	long	pfkey_init_phase2( bool nailed, u_int16_t plcytype, u_int32_t plcyid, u_int32_t seq );
+	long	pfkey_init_phase2( bool nail, u_int16_t plcytype, u_int32_t plcyid, u_int32_t seq );
 
 	long	pfkey_recv_spadd( PFKI_MSG & msg );
 	long	pfkey_recv_spnew( PFKI_MSG & msg );
