@@ -730,9 +730,11 @@ typedef class _IDB_PH2 : public IDB_XCH_SA
 	IKE_COOKIES	cookies;
 	uint32_t	seqid_in;
 	uint32_t	seqid_out;
-	uint32_t	nailed_plcyid;
-	long		spicount;
+	uint32_t	plcyid_in;
+	uint32_t	plcyid_out;
 
+	bool		nailed;
+	long		spicount;
 	long		dhgr_id;
 
 	IKE_PH2ID	ph2id_ls;
@@ -826,7 +828,7 @@ typedef class _IDB_CFG : public IDB_XCH
 	IKE_ATTR *	attr_get( long index );
 	bool		attr_has( unsigned short atype );
 	bool		attr_add_b( unsigned short atype, unsigned short adata );
-	bool		attr_add_v( unsigned short atype, void * vdata, size_t size );
+	bool		attr_add_v( unsigned short atype, const void * vdata, size_t size );
 
 	long		attr_count();						// get attribute count
 	void		attr_reset();						// reset attribute list
