@@ -829,7 +829,7 @@ long _ITH_IPCC::io_recv( void * data, size_t size, size_t & rcvd )
 	switch( result )
 	{
 		case ERROR_SUCCESS:
-			assert( size == dwsize );
+//			assert( size == dwsize );
 			result = IPCERR_OK;
 			break;
 
@@ -842,6 +842,7 @@ long _ITH_IPCC::io_recv( void * data, size_t size, size_t & rcvd )
 			result = IPCERR_WAKEUP;
 			break;
 
+		case ERROR_GEN_FAILURE:
 		case ERROR_BROKEN_PIPE:
 		case ERROR_INVALID_HANDLE:
 			result = IPCERR_CLOSED;
@@ -922,6 +923,7 @@ long _ITH_IPCC::io_send( void * data, size_t size, size_t & sent )
 			result = IPCERR_BUFFER;
 			break;
 
+		case ERROR_GEN_FAILURE:
 		case ERROR_BROKEN_PIPE:
 		case ERROR_INVALID_HANDLE:
 			result = IPCERR_CLOSED;
@@ -1228,6 +1230,7 @@ long _ITH_IPCS::inbound( const char * path, IPCCONN & ipcconn )
 			result = IPCERR_WAKEUP;
 			break;
 
+		case ERROR_GEN_FAILURE:
 		case ERROR_BROKEN_PIPE:
 		case ERROR_INVALID_HANDLE:
 			result = IPCERR_CLOSED;
